支付宝非官方Python API
=======================================

.. image:: https://travis-ci.org/lxneng/alipay.png?branch=master
   :target: https://travis-ci.org/lxneng/alipay

.. image:: https://pypip.in/d/alipay/badge.png
        :target: https://crate.io/packages/alipay/

介绍
---------------------------------------

支付宝非官方Python API


参考资料
---------------------------------------

- `ruby alipay gem <https://github.com/chloerei/alipay>`_
- `支付宝 API 向导（Ruby 版） <http://blog.chloerei.com/articles/51-alipay-payment-in-ruby>`_
- `官方文档 <https://b.alipay.com/order/techService.htm>`_
